==> KayPacha-0.0.3.tar.gz: KayPacha-0.0.3/kaypacha/models/siiu/graph_fields_project.py <==
##
# project fields
##
project_fields = {}
project_fields["SIIU_PROYECTO"] = {"alias": "project"}
project_fields["SIIU_PROYECTO"]["fields"] = {
}

project_fields["SIIU_COMPROMISO_POR_PROYECTO"] = {"alias": "project_commitment"}
project_fields["SIIU_COMPROMISO_POR_PROYECTO"]["fields"] = {
}

project_fields["SIIU_COMPROMISO"] = {"alias": "commitment"}
project_fields["SIIU_COMPROMISO"]["fields"] = {
}

project_fields["SIIU_ETAPA_PROYECTO"] = {"alias": "project_stage"}
project_fields["SIIU_ETAPA_PROYECTO"]["fields"] = {
}

project_fields["SIIU_ESTADO_PROYECTO"] = {"alias": "project_state"}
project_fields["SIIU_ESTADO_PROYECTO"]["fields"] = {
}

project_fields["SIIU_AVAL_APROBACION"] = {"alias": "aprob_aval"}
project_fields["SIIU_AVAL_APROBACION"]["fields"] = {
}

project_fields["SIIU_ACTUALIZACION_PROYECTO"] = {"alias": "project_update"}
project_fields["SIIU_ACTUALIZACION_PROYECTO"]["fields"] = {
}

project_fields["SIIU_EVALUACION_TECNICA"] = {"alias": "technical_eval"}
project_fields["SIIU_EVALUACION_TECNICA"]["fields"] = {
}

project_fields["SIIU_EVALUACION_CIENTIFICA"] = {"alias": "cientific_eval"}
project_fields["SIIU_EVALUACION_CIENTIFICA"]["fields"] = {
}

project_fields["SIIU_EVALUADOR_RECOMENDADO"] = {"alias": "recommended_evaluator"}
project_fields["SIIU_EVALUADOR_RECOMENDADO"]["fields"] = {
}

project_fields["SIIU_EVALUADOR"] = {"alias": "evaluator"}
project_fields["SIIU_EVALUADOR"]["fields"] = {
}

project_fields["SIIU_PARTICIPANTE_PROYECTO"] = {"alias": "project_participant"}
project_fields["SIIU_PARTICIPANTE_PROYECTO"]["fields"] = {
}

project_fields["SIIU_ROL_PARTICIPANTE_PROYECTO"] = {"alias": "project_participant_role"}
project_fields["SIIU_ROL_PARTICIPANTE_PROYECTO"]["fields"] = {
}

project_fields["SIIU_GRUPO"] = {"alias": "group"}
project_fields["SIIU_GRUPO"]["fields"] = {
}

project_fields["SIIU_APORTANTE_PROYECTO"] = {"alias": "project_contributor"}
project_fields["SIIU_APORTANTE_PROYECTO"]["fields"] = {
}

project_fields["SIIU_SEGUIMIENTO_APORTANTE"] = {"alias": "contributor_follow_up"}
project_fields["SIIU_SEGUIMIENTO_APORTANTE"]["fields"] = {
}

project_fields["SIIU_MODIFICACION_PRESUPUESTAL"] = {"alias": "budget_modification"}
project_fields["SIIU_MODIFICACION_PRESUPUESTAL"]["fields"] = {
}

project_fields["SIIU_CLASE_PROYECTO"] = {"alias": "project_class"}
project_fields["SIIU_CLASE_PROYECTO"]["fields"] = {
}

project_fields["SIIU_NIVEL_PROYECTO"] = {"alias": "project_level"}
project_fields["SIIU_NIVEL_PROYECTO"]["fields"] = {
}

project_fields["SIIU_SUBNIVEL_PROYECTO"] = {"alias": "project_sublevel"}
project_fields["SIIU_SUBNIVEL_PROYECTO"]["fields"] = {
}

project_fields["SIIU_TIPO_PROYECTO"] = {"alias": "project_type"}
project_fields["SIIU_TIPO_PROYECTO"]["fields"] = {
}

project_fields["SIIU_SUBTIPO_PROYECTO"] = {"alias": "project_subtype"}
project_fields["SIIU_SUBTIPO_PROYECTO"]["fields"] = {
}

project_fields["SIIU_TEXTO_DESCRIPTIVO"] = {"alias": "descriptive_text"}
project_fields["SIIU_TEXTO_DESCRIPTIVO"]["fields"] = {
}

project_fields["SIIU_TEXTO_SOLICITADO"] = {"alias": "requested_text"}
project_fields["SIIU_TEXTO_SOLICITADO"]["fields"] = {
}

project_fields["SIIU_DOCUMENTO_PROYECTO"] = {"alias": "project_doc"}
project_fields["SIIU_DOCUMENTO_PROYECTO"]["fields"] = {
}

project_fields["SIIU_DOCUMENTO_SOPORTE"] = {"alias": "support_doc"}
project_fields["SIIU_DOCUMENTO_SOPORTE"]["fields"] = {
}

project_fields["SMAP_PROYECTO_IFORMAL"] = {"alias": "iformal"}
project_fields["SMAP_PROYECTO_IFORMAL"]["fields"] = {
}

project_fields["SIIU_DATOS_SUBPROYECTOS"] = {"alias": "subproject_data"}
project_fields["SIIU_DATOS_SUBPROYECTOS"]["fields"] = {
}

project_fields["SMAP_SOLICITUD_ADM"] = {"alias": "adm_request"}
project_fields["SMAP_SOLICITUD_ADM"]["fields"] = {
}

project_fields["SIIU_COMPONENTE_PROYECTO"] = {"alias": "project_component"}
project_fields["SIIU_COMPONENTE_PROYECTO"]["fields"] = {
}

project_fields["SIIU_DETALLE_MODIF_PPTAL"] = {"alias": "budget_modification_details"}
project_fields["SIIU_DETALLE_MODIF_PPTAL"]["fields"] = {
}

project_fields["SIIU_SEGUIMIENTO_PRESUPUESTO"] = {"alias": "budget_follow_up"}
project_fields["SIIU_SEGUIMIENTO_PRESUPUESTO"]["fields"] = {
}

project_fields["SIIU_SEGUIMIENTO_PPTO_INICIAL"] = {"alias": "initial_budget_follow_up"}
project_fields["SIIU_SEGUIMIENTO_PPTO_INICIAL"]["fields"] = {
}

project_fields["SMAP_SOL_ADICION_PRESUPUESTAL"] = {"alias": "budget_addition_request"}
project_fields["SMAP_SOL_ADICION_PRESUPUESTAL"]["fields"] = {
}

project_fields["SMAP_SOLICITUD_CAMBIO_RUBRO"] = {"alias": "item_change_request"}
project_fields["SMAP_SOLICITUD_CAMBIO_RUBRO"]["fields"] = {
}

project_fields["SIIU_ETAPA_PROCESO_SELECCION"] = {"alias": "selection_process_stage"}
project_fields["SIIU_ETAPA_PROCESO_SELECCION"]["fields"] = {
}

project_fields["SIIU_FECHA_PROCESO_SELECCION"] = {"alias": "selection_process_date"}
project_fields["SIIU_FECHA_PROCESO_SELECCION"]["fields"] = {
}

project_fields["SIIU_PERSONA_NATURAL"] = {"alias": "natural_person"}
project_fields["SIIU_PERSONA_NATURAL"]["fields"] = {
}

project_fields["SIIU_PERSONA_JURIDICA"] = {"alias": "legal_entity"}
project_fields["SIIU_PERSONA_JURIDICA"]["fields"] = {
}

==> KayPacha-0.0.5.tar.gz: KayPacha-0.0.5/kaypacha/models/siiu/graph_fields_project.py <==
##
# project fields
##
project_fields = {}
project_fields["SIIU_PROYECTO"] = {"alias": "project"}
project_fields["SIIU_PROYECTO"]["fields"] = {
}

project_fields["SIIU_COMPROMISO_POR_PROYECTO"] = {
    "alias": "project_commitment"}
project_fields["SIIU_COMPROMISO_POR_PROYECTO"]["fields"] = {
}

project_fields["SIIU_COMPROMISO"] = {"alias": "commitment"}
project_fields["SIIU_COMPROMISO"]["fields"] = {
}

project_fields["SIIU_ETAPA_PROYECTO"] = {"alias": "project_stage"}
project_fields["SIIU_ETAPA_PROYECTO"]["fields"] = {
}

project_fields["SIIU_ESTADO_PROYECTO"] = {"alias": "project_state"}
project_fields["SIIU_ESTADO_PROYECTO"]["fields"] = {
}

project_fields["SIIU_AVAL_APROBACION"] = {"alias": "endorsement_approval"}
project_fields["SIIU_AVAL_APROBACION"]["fields"] = {
}

project_fields["SIIU_ACTUALIZACION_PROYECTO"] = {"alias": "project_update"}
project_fields["SIIU_ACTUALIZACION_PROYECTO"]["fields"] = {
}

project_fields["SIIU_EVALUACION_TECNICA"] = {"alias": "technical_eval"}
project_fields["SIIU_EVALUACION_TECNICA"]["fields"] = {
}

project_fields["SIIU_EVALUACION_CIENTIFICA"] = {"alias": "scientific_eval"}
project_fields["SIIU_EVALUACION_CIENTIFICA"]["fields"] = {
}

project_fields["SIIU_EVALUADOR_RECOMENDADO"] = {
    "alias": "recommended_evaluator"}
project_fields["SIIU_EVALUADOR_RECOMENDADO"]["fields"] = {
}

project_fields["SIIU_EVALUADOR"] = {"alias": "evaluator"}
project_fields["SIIU_EVALUADOR"]["fields"] = {
}

project_fields["SIIU_PARTICIPANTE_PROYECTO"] = {"alias": "project_participant"}
project_fields["SIIU_PARTICIPANTE_PROYECTO"]["fields"] = {
}

project_fields["SIIU_ROL_PARTICIPANTE_PROYECTO"] = {
    "alias": "project_participant_role"}
project_fields["SIIU_ROL_PARTICIPANTE_PROYECTO"]["fields"] = {
}

project_fields["SIIU_GRUPO"] = {"alias": "group"}
project_fields["SIIU_GRUPO"]["fields"] = {
}

project_fields["SIIU_APORTANTE_PROYECTO"] = {"alias": "project_contributor"}
project_fields["SIIU_APORTANTE_PROYECTO"]["fields"] = {
}

project_fields["SIIU_SEGUIMIENTO_APORTANTE"] = {
    "alias": "contributor_follow_up"}
project_fields["SIIU_SEGUIMIENTO_APORTANTE"]["fields"] = {
}

project_fields["SIIU_MODIFICACION_PRESUPUESTAL"] = {
    "alias": "budget_modification"}
project_fields["SIIU_MODIFICACION_PRESUPUESTAL"]["fields"] = {
}

project_fields["SIIU_CLASE_PROYECTO"] = {"alias": "project_class"}
project_fields["SIIU_CLASE_PROYECTO"]["fields"] = {
}

project_fields["SIIU_NIVEL_PROYECTO"] = {"alias": "project_level"}
project_fields["SIIU_NIVEL_PROYECTO"]["fields"] = {
}

project_fields["SIIU_SUBNIVEL_PROYECTO"] = {"alias": "project_sublevel"}
project_fields["SIIU_SUBNIVEL_PROYECTO"]["fields"] = {
}

project_fields["SIIU_TIPO_PROYECTO"] = {"alias": "project_type"}
project_fields["SIIU_TIPO_PROYECTO"]["fields"] = {
}

project_fields["SIIU_SUBTIPO_PROYECTO"] = {"alias": "project_subtype"}
project_fields["SIIU_SUBTIPO_PROYECTO"]["fields"] = {
}

project_fields["SIIU_TEXTO_DESCRIPTIVO"] = {"alias": "descriptive_text"}
project_fields["SIIU_TEXTO_DESCRIPTIVO"]["fields"] = {
}

project_fields["SIIU_TEXTO_SOLICITADO"] = {"alias": "requested_text"}
project_fields["SIIU_TEXTO_SOLICITADO"]["fields"] = {
}

project_fields["SIIU_DOCUMENTO_PROYECTO"] = {"alias": "project_doc"}
project_fields["SIIU_DOCUMENTO_PROYECTO"]["fields"] = {
}

project_fields["SIIU_DOCUMENTO_SOPORTE"] = {"alias": "support_doc"}
project_fields["SIIU_DOCUMENTO_SOPORTE"]["fields"] = {
}

project_fields["SMAP_PROYECTO_IFORMAL"] = {"alias": "iformal"}
project_fields["SMAP_PROYECTO_IFORMAL"]["fields"] = {
}

project_fields["SIIU_DATOS_SUBPROYECTOS"] = {"alias": "subproject_data"}
project_fields["SIIU_DATOS_SUBPROYECTOS"]["fields"] = {
}

project_fields["SMAP_SOLICITUD_ADM"] = {"alias": "adm_request"}
project_fields["SMAP_SOLICITUD_ADM"]["fields"] = {
}

project_fields["SIIU_COMPONENTE_PROYECTO"] = {"alias": "project_component"}
project_fields["SIIU_COMPONENTE_PROYECTO"]["fields"] = {
}

project_fields["SIIU_DETALLE_MODIF_PPTAL"] = {
    "alias": "budget_modification_details"}
project_fields["SIIU_DETALLE_MODIF_PPTAL"]["fields"] = {
}

project_fields["SIIU_SEGUIMIENTO_PRESUPUESTO"] = {"alias": "budget_follow_up"}
project_fields["SIIU_SEGUIMIENTO_PRESUPUESTO"]["fields"] = {
}

project_fields["SIIU_SEGUIMIENTO_PPTO_INICIAL"] = {
    "alias": "initial_budget_follow_up"}
project_fields["SIIU_SEGUIMIENTO_PPTO_INICIAL"]["fields"] = {
}

project_fields["SMAP_SOL_ADICION_PRESUPUESTAL"] = {
    "alias": "budget_addition_request"}
project_fields["SMAP_SOL_ADICION_PRESUPUESTAL"]["fields"] = {
}

project_fields["SMAP_SOLICITUD_CAMBIO_RUBRO"] = {
    "alias": "item_change_request"}
project_fields["SMAP_SOLICITUD_CAMBIO_RUBRO"]["fields"] = {
}

project_fields["SIIU_ETAPA_PROCESO_SELECCION"] = {
    "alias": "selection_process_stage"}
project_fields["SIIU_ETAPA_PROCESO_SELECCION"]["fields"] = {
}

project_fields["SIIU_FECHA_PROCESO_SELECCION"] = {
    "alias": "selection_process_date"}
project_fields["SIIU_FECHA_PROCESO_SELECCION"]["fields"] = {
}

project_fields["SIIU_PERSONA_NATURAL"] = {"alias": "natural_person"}
project_fields["SIIU_PERSONA_NATURAL"]["fields"] = {
}

project_fields["SIIU_PERSONA_JURIDICA"] = {"alias": "legal_entity"}
project_fields["SIIU_PERSONA_JURIDICA"]["fields"] = {
}

project_fields["SIIU_CONVOCATORIA"] = {"alias": "call"}
project_fields["SIIU_CONVOCATORIA"]["fields"] = {
}
project_fields["SIIU_MODALIDAD_CONVOCATORIA"] = {"alias": "call_modality"}
project_fields["SIIU_MODALIDAD_CONVOCATORIA"]["fields"] = {
}
